AppUsageInfo class

Information on app usage.

Constructors

AppUsageInfo(String name, double usageInSeconds, DateTime _startDate, DateTime _endDate, DateTime _lastForeground)

Properties

appName → String
The name of the application
no setter
endDate → DateTime
The end of the interval
no setter
hashCode → int
The hash code for this object.
no setterinherited
lastForeground → DateTime
Last time app was in foreground
no setter
packageName → String
The name of the application package
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate → DateTime
The start of the interval
no setter
usage → Duration
The amount of time the application has been used in the specified interval
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited